import React, { RefObject } from "react";
import {
  StyledComponent,
  GlobalStyleComponent,
  DefaultTheme,
} from "styled-components";

import { SwiperOptions } from "swiper";

export interface ButtonProps {
  size?: "small" | "large";
  variant?: "redpink" | "white";
  tel?: boolean;
  dot?: boolean;
}

declare const Button: StyledComponent<"button", any, ButtonProps, never>;

declare const MobileButton: StyledComponent<"button", any, ButtonProps, never>;

export interface NavTabProps {
  title: string;
  active?: boolean;
  variant?: "black" | "white";
}

declare const NavTab: React.FunctionComponent<NavTabProps>;

declare const NavTabItem: StyledComponent<
  "li",
  any,
  {
    active: boolean;
  },
  never
>;

export interface TitleProps {
  text: Array<string>;
  caption?: string;
  exclusive?: boolean;
  space?: number;
  center?: boolean;
}

declare const Title: React.FunctionComponent<TitleProps>;

export interface PhotoCardProps {
  src: string;
  deco?: "type1" | "type2" | "type3";
  width?: number;
  exclusive?: boolean;
}

declare const PhotoCard: React.FunctionComponent<PhotoCardProps>;

export interface MiniCardProps {
  title: string;
  subtitle: string;
  image: string;
  space: number;
  width?: number;
  caption?: string;
  size?: "small" | "large";
  exclusive?: boolean;
}

declare const MiniCard: React.FunctionComponent<MiniCardProps>;

declare const MiniCards: StyledComponent<"div", any, {}, never>;

export interface TitleToggleSwitchProps {
  toggle: boolean;
  handleToggle: () => void;
  title: [string, string];
}

declare const TitleToggleSwitch: React.FunctionComponent<TitleToggleSwitchProps>;

export interface IconListProps {
  data: Array<{
    icon: string;
    title: Array<string>;
    description: string;
  }>;
  exclusive?: boolean;
}

declare const IconList: React.FunctionComponent<IconListProps>;

declare const TextCard: StyledComponent<"div", any, {}, never>;

export interface ArrowLinkProps {
  variant: "white" | "redpink";
  direction: "east" | "north-east";
  link: string;
  onClick?: () => void;
  children?: string;
}

declare const ArrowLink: React.FunctionComponent<ArrowLinkProps>;

export interface NavigationProps {
  variant: "white" | "transparent";
}

declare const Navigation: React.FunctionComponent<NavigationProps>;

export interface CounterProps {
  num: number;
  title?: string;
  fixed?: string;
}

declare const Counter: React.FunctionComponent<CounterProps>;

export interface DraggableProps { }

declare const Draggable: React.FunctionComponent<DraggableProps>;

export interface SectionProps { }

declare const Section: StyledComponent<"section", any, SectionProps, never>;

export interface ArticleProps {
  center?: boolean;
  reverse?: boolean;
  breakPoint?: "mobile" | "tablet";
  column?: boolean;
}

declare const Article: StyledComponent<"article", any, ArticleProps, never>;

export interface NavSlideProps {
  show: boolean;
  onClose: () => void;
}

declare const NavSlide: React.FunctionComponent<NavSlideProps>;

export interface NavSlideItemProps {
  active: boolean;
  title: string;
  handleLink?: () => void;
}

declare const NavSlideItem: React.FunctionComponent<NavSlideItemProps>;

declare const NavSlideItemChild: StyledComponent<
  "span",
  any,
  {
    active: boolean;
  },
  never
>;

export interface NavSlideButtonProps {
  variant: "white" | "black";
}

declare const NavSlideButton: StyledComponent<
  "button",
  any,
  NavSlideButtonProps,
  never
>;

declare const NavSlideFooter: StyledComponent<"div", any, {}, never>;

export interface ModalProps {
  show: boolean;
  onClose: () => void;
  closeButton?: boolean;
}

declare const Modal: React.FunctionComponent<ModalProps>;

export interface NemoSwiperProps extends SwiperOptions { }

declare const NemoSwiper: React.FunctionComponent<NemoSwiperProps>;

interface BaseFormProps {
  value: string;
  label: string;

  required?: boolean;
  isValid?: boolean;
}

export interface TextProps extends BaseFormProps {
  onChange: React.ChangeEventHandler<HTMLInputElement>;
  placeholder?: string;
  maxLength?: number;
  type?: string;
}

declare const Text: React.FunctionComponent<TextProps>;

export interface SelectProps extends BaseFormProps {
  onChange: (value: string) => void;
  options: Array<any>;
  show: any;
  onClick: () => void;
}

declare const Select: React.FunctionComponent<SelectProps>;

export interface FileProps extends BaseFormProps {
  onChange: (link: string) => void;
  downloadButton?: {
    label: string;
    link: string;
  },
  comment?: string;
  handleFileUrl?: (e: any) => void;
  handleLink?: (e: any) => void;
}

declare const File: React.FunctionComponent<FileProps>;

export interface AgreeProps {
  title: string;
  caution: Array<string>;
}

declare const Agree: React.FunctionComponent<Agree>;

export interface GlobalStyleProps { }

declare const GlobalStyle: GlobalStyleComponent<GlobalStyleProps, DefaultTheme>;

declare const useScrollLocation: () => number;

declare const useCounterAnimation: (
  number: number,
  counter: RefObject<any>
) => number;
